' code snippet file for use with shivaEngine3 
' released: 5.25.06
'
' *** COPYRIGHT NOTICE ***
'
' written by shiva
' Thanks to all the other authors
' Contact Info : p_d_sanderson@hotmail.com
'
' All rights are reserved by p.d.sanderson (shiva)
' You may release, or modify for release any portion of this product, as long as it is not 
' part of a commercial product or venture. 
' This code snippet was meant to be expanded, so please contact the author for additions 
' to this base script. All submissions welcome.
'
' The above copyright and remarks MUST be included with this table. Please credit use of
' this script for your own tables.
'
' Please keep any modifications for release as separate code snippet files so others can use 
' it for their tables.
'
' NOTE: THE FOLLOWING IS THE MOST COMPLEX PART OF THE CODE FOR PLAYBOY
' Beginners may get lost with this, because this feature turns on so many things, so i tried my best
' to explain it. This is really for intermediate coders, but I wrote it for beginners to understand
' better.
'
' *** 1823 - (Playboy) Keys / Grotto ***
'
' The keys portion To Playboy is very complex, as it handles the key scoring, the Grotto scoring
' Bonus multiplier, and other scoring all in one.
 
Dim KEYS1823Count ' Holds value for amount of times all 5 Keys are made
 
Sub SetKeys1823()
 
 	' Main routine for start of game and at every new ball. Because we use the memory feature here, we
 	' have different code depending on the skill level selected
 
 	' Reset variable to switch off keys. If we don't do this, this value will carry on to the next player
 
	KEYS1823Count=0 
 
 	' Now we have code that will reset the key lights, so the player will have to relight them at the
 	' start of every ball. Note that all the other lights will stay on and score, as they are stored
 	' in the memory
 
 	If SetSkillLevel>1 or Gameover=1 then
		For Each Light in LightKeys 'resets matching Key Lights
			light.state = 0
		Next
 	end if
 
 	' because every time the keys are made, it switches on a score feature. We use the KEYS1823Count variable
 	' to track that, so we use the lights that are switched on at the previous ball, and stored in memory.
 	' When those lights are on at the start of a new ball, we look at the lights, and add back in the value 
 	' for KEYS1823Count, so the game doesn't lose track from player to player. Note we also have code for
 	' the multiplier lights and 20k bonus light as well. It could be included as part of the engine, but
 	' you may want the fine control as well, so you will have to include it as part of your code.
 
 		If LightGrotto25k.State=1 then KEYS1823Count= 1
 		If LightKeySpecial.State=1 then KEYS1823Count= 3
 		If Light2x.State=1 then mult=2
 		If Light3x.State=1 then mult=3
 		If Light4x.State=1 then mult=4
 
 	' this is for if the 20K is lit. Note we add 19 bonus first, then a AddBonus(). We do this so it
 	' forces the system to have 20 bonus in it's memory, and not automatically light the 1k light as well.
 
 		If Light20k.State=1 then 
 			bonus=19
 			AddBonus()
 		end if
 
 	KeyBT1823z1.IsDropped=1 ' Can't forget the push effect single button target down
 
End sub 
 
' Because of the nature of collections, you can't mix or match objects, so we cheat. The 5th
' key is a button target, so we add a "Fake" custom trigger, so we can save a lot of code
' Also, the button adds a Bonus (the other keys don't), so what we do is just use the 4
' triggers for the playboy (grotto) lights, and have a separate code just for the target,
' so we can have that bonus, and the pushed back effect.
 
' Button Target Hit Code
' Because the Playboy Key feature uses 4 rollover triggers, and 1 Button Target to score keys
' we need to define the Button Target code separate from the rollovers. This has a "pushed in" effect
' using 2 targets. If you hit the first target, it drops that target, and pops up a second target behind
' it, so it looks like the ball has "pushed" the button target back. We then use the built in timer of the 
' first target (KeyBT1823x1) to reverse, drop the back target and pop up the front target again. 
' You have to set the interval (in milliseconds) in the editor. Find the target, click on it and using the
' options find the misc section. Make sure the TimerEnabled field is CHECKED, and set the interval in the 
' Timer Interval field. A good value to start with is 100 (1000 miliseconds = 1 second)
 
Sub KeyBT1823x1_Hit()
 
 	KeyBT1823x1.IsDropped=1 ' drops first target so we get the...
  	KeyBT1823z1.IsDropped=0	' pushed in effect, as we pop a target just behind the first
  	KeyBT1823x1.TimerEnabled=1 ' we use the built in timer for the effect
 
 	' check for tilted state, if not, then execute the scoring/ light code
 
  	if tilt=0 and gameover=0 then
 
  		AddBonus()
 		
 		' Because the button Target is coded differently than a switch, we have to add a special
 		' line of code, so it's reconized as part of the key system. To do so, we point to the
 		' Key_Hit subroutine, and then the number in brackets is the value for that key.
 		' Just a side note, it's the 5th key, but because of the scripting, we have the key
 		' variable set from 0 to 4 (which equals 5 total)
 
 		Keys_Hit(4)
	
  	end if
 
End Sub

 ' We need to use the timer now, which will execute the following code after the amount of time the
 ' interval is set.
 ' This reverses the effect of the pushed in effect, so it "pushes back out"
 
Sub KeyBT1823x1_Timer()
 
 	KeyBT1823x1.TimerEnabled=0 ' switch off the timer first
 
 	' now we reset the button target back.
 
 	KeyBT1823x1.IsDropped=0 ' drops first target so we get the...
  	KeyBT1823z1.IsDropped=1	' pushed in effect, as we pop a target just behind the first
 
End sub
 
' The button target just handles the push back effect, and add's one bonus, so now
' it's time to handle the switches. We don't need to drop the wire triggers, as it's so
' high up the table, people wouldn't notice anyway, and saves a bit of time as well.
' The triggers all use the same sound, and score, so it's like the Target and Calendar
' collections in the set up.
 
' Match the triggers with the lights, and if they are all on run the code to tell the system what to do next. 
' Also with Playboy, you have to tie in the bonus multiplier system as well, AND the grotto feature, 
' so this will have the most code. It's very complex, so follow the remarks carefully, as there are multiple
' features lit and used all tied into the Keys

' This is the Main routine. 
 ' We use a couple of collections here, as it makes things so much more easier. 
' We create our 4 Trigger objects here (we only need 4 as we have a Button Target as well) and set them
' in the editor using the options. Each trigger uses the Shaped Custom setting, so we can shape the trigger
' and we make sure the State field is Enabled (checked). I named mine Key1823a1 for the first trigger
' and Key1823a2, Key1823a3, and Key1823a3 for the others. Note that I kept the same name for each trigger, 
' I just added a different number at the end so I can use the Index feature without getting confused.
' We then create a Keys collection in the collection manager ( Tables/Collection Manager at the top menu)
' and then added the Triggers to the collection. They should be in the same order from top to bottom in the 
' collection listing as the numbers, Key1823a1 at the top, Key1823a4 at the bottom.
'
' I then added a second collection, for the Lights, and called it LightKeys in the collection manager.
' I created my lights (Need 5) to indicate which key is made, named it LightKey1 to LightKey5. I
' made sure I have the same last number as the triggers, so it makes it very easy to code, as 
' the Key1823a1 has LightKey1 as it's light, and so on. The Button Target is Key 5, so it has LightKey5
' assigned to it. Like the Keys collection, make sure the order matches, LightKey1 to LightKey5 listed
' in that collection.
'
' As metioned above though, PlayBoy tied everything in the keys, including the Grotto. I use the code to
' turn on the Grotto light with a key light, again using another collection, and again it should match
' by number with the other two. So a Key hit will light the light for that key, and the corresponding light
' in the Grotto lane as well. The collection for the Grotto is called LightGrotto, and has the 5 Grotto
' Grotto lights included as part of that collection.
'
' Because the Grotto is a Kicker, I need one of those, so I create one in the editor, and call it
' KickerGrotto. I select "KickerHidden" in the field (optional of course), make sure the state is  
' Enabled, so it's Checked. The kicker has it's own built in timer, but I use code, so the TimerEnabled
' field has to be UNCHECKED. I still set the interval below to 1000 (one second)
'
' Finally, I need 2 timer objects for all of this. I created a Timer in the editor (the icon in the editor 
' looks like a clock) and in the options named it "TimerKeys". I kept TimerEnabled UNCHECKED, but I added a
' value of 100 to the interval (in milliseconds of course). This really isn't important, but I wanted
' that slight delay before the lights switched back off, so you see that last key light, before all the
' Key Lights switches back off.
'
' The Grotto needs a timer as well, so I create a second timer, call it "TimerGrotto". Like the first 
' Timer, I kept TimerEnabled UNCHECKED, but the interval is not important (leave it alone) as I use code
' to set the intervals. The TimerGrotto routine actually does double duty. I set a interval as a delay
' for when the ball is in the Grotto kicker, so I can play a sound, and then, I call up the timer routine
' and set the interval within that code as the time I want to delay for each Grotto bonus count. If
' you look at it this way, the Grotto is really a very basic bonus countdown system, but separate, so
' the code is very similar to that of a actual bonus countdown at the end of a ball.
 
Sub Keys_Hit(Index)
 
	' SetNewBall() sub HOOK has code to turn these lights off at start of each new ball and reset the keys
 
  	' now we start checking the routine, first make sure the game isn't in a tilt state
 	' gameover is the variable that tells the script if there's a game in progress or not. we use this
 	' to prevent execution of the code in Light Attract mode
 
  	If tilt=0 and gameover=0 then
 
 		addscore 500 ' adds 500 points
 
 	' stop sounds if playing. There's a built-in routine within the engine that stops the sounds
 	' that are included with the template. This is very handy, as it prevents multiple sounds from
 	' playing at once, which is rather ear jarring sometimes

   		StopAllSounds()
 
 	' Play the sound
 
  		' we use the GetScoreBells variable to decide if we want to use the built in sound
		' system for Bally/EM type scoring or not. If we don't then set GetScoreBells to 0
		' and add the sound here. The GetScoreBells feature, if on (GetBalls=1) will play a set
		' sound, and is already added to the engine
		If GetScoreBells=0 then PlaySound "ButtonOff"
  
 	' We use the light collection to control this, as it's just as simple as a variable. 
 	' Just make sure the amount of lights in that collection match the target amounts in it's collections. 
 	' We turn on the matching lights, and do this before we check all the lights are on, so the additional 
 	' code that follows will be executed properly.
 
  		LightKeys( Index ).state = 1 ' light the matching light to the target
 
  	' Since the game also lights the corresponding Grotto light, lets do that the same way as the key lights
 
  		LightGrotto( Index ).state = 1 ' light the matching light to the target
 
 	' Of course, the pin settings had the ability to set the 1 and 4, and the 2 and 3 keys tied together
 	' so lets do that. It's set to the skill level, on hard, it's turned off. The top keys were very hard
 	' to make, so most arcade versions had them tied.
 
 	If SetSkillLevel <1 then
 
 		' Remember, the index feature starts at 0 for key 1, and ends at 4 for Key 5, so the Index number
 		' is one less than the Key number in the editor. Since the button target has it's own code, we don't
 		' need to add anything for it here in the case settings
 
 		Select Case Index
 
 			case 0
 				LightKeys( Index+3).state = 1
 				LightGrotto( Index+3).state = 1
 				Addscore 500 ' don't forget to add score for that rollover
 
 			case 1
 				LightKeys( Index+1).state = 1
 				LightGrotto( Index+1 ).state = 1
 				Addscore 500 ' don't forget to add score for that rollover
 
 			case 2
 				LightKeys( Index-1).state = 1
 				LightGrotto( Index-1 ).state = 1
 				Addscore 500 ' don't forget to add score for that rollover
 
 			case 3
 				LightKeys( Index-3).state = 1
 				LightGrotto( Index-3).state = 1
 				Addscore 500 ' don't forget to add score for that rollover
 
 		end select
 	end if
 			

 	' Remember what I said that Playboy seemed to tie in everything through the keys? It also tied in a
 	' feature where every 3rd hit of the keys, targets and calendar would light the Railway lane (right side
 	' of the Drop Target Bank) for 5000 points. On top of that, it also would alternate the lights in the
 	' Outlane (if they were turned on) with every hit as well. We have to add this code as well, but 
 	' because there are Targets and button Target routines that do this as well, we write a separate sub
 	' that we just point to instead to handle that. Saves a lot of coding...
 
 	' Adds count to Railway Feature for 5000 points (every 3rd time) Other objects also trigger
 	' the count as well. See the Railway section within the code for a more detailed description
 
 		GetSpecialFeatureCount()
 		
 	' The same, but for if the Outlanes are lit (This will change with every hit though)
 
 		AlternateOutlaneLights()
 
 	' Basic setup is done, so lets see how many Keys have been made. We use the light state for this, a
 	' lot of authors will use a variable instead, but this is so much simplier

 	' We call the collection, and tell the script to look at each light in the collection
 
		For	each light in LightKeys
 
 			' This looks to see if any of the lights in that collection are unlite, or Off
 			' If ALL the lights are on, then this will be ignored
 
 			If Light.state=0 Then ' if lights are OFF.
 				'if the lights are OFF, exit this sub now, do not do the next code
 				Exit sub 
 			end if
 
  		Next
 
 	' Now we handle if the Key lights are all ON
 	' We need a variable here, which we use to keep track of how many times we have lit all 5 keys
 	' It's set to 0 at the start of a game in the SetNewBall() HOOK, so all we have to do is tell
 	' it to increase that value by one.
 
		KEYS1823Count=KEYS1823Count+1
 
 	' Playboy also increased the Multiplier when all keys were made, so we call the AddMultiplier
 	' sub that's part of the engine. It also kept the multiplier in memory, as it's tied in with the keys.
 	' If you write your own code for your own table, just put
 	' AddMultiplier() where you want in your code to do the same.
 
  	' Now we use a case setting to give special instructions on what we want to happen with each
 	' 5 keys made. You can add anything here, from multipliers, extra balls, specials
 	' whatever. we have case statements here, so it will execute case 1 first, then case 2
 	' will execute the 2nd time a bank is made and so on. 
 	' Case Else means everytime after all the cases are done, which in Playboy,  lights yet 
 	' another Bally Special.
 	' You can have as many cases as you want.
 
 		Select Case KEYS1823Count
 
 			Case 1 ' lights 2x
 				' Don't forget the Grotto Lights
 				' The 25k light goes on. It also adds the bonus for each light
 				LightGrotto25k.State=1
 				AddMultiplier()' Add bonus multiplier
 
 			Case 2 ' lights 3x
 				AddMultiplier()' Add bonus multiplier
				' No need to put anything here, so leave it blank
 
 			Case 3 ' lights 5x
 				AddMultiplier()' Add bonus multiplier
  				LightKeySpecial.State=1 ' light Special
 
 			Case Else ' keep doing this after case 3
 				' Everytime after this, the game will score a special
  				GetSpecial()
 
 		End Select

 	' and run a timer, so we can reset it back after the delay interval you have set in the editor 
 	' for the TimerKeys timer. It just looks nicer is all. 
 
  		TimerKeys.Enabled=1
 
  	end if
 
End Sub
 
 ' This is for that "unimportant" timer that is used to delay the lights being switched off. It's really
 ' a polish thing more than anything else.
 
Sub TimerKeys_Timer()
 
  	TimerKeys.Enabled=0 ' switches off the timer
 
 	' We do our checked to see if we are playing a game, because during attract mode, the lights won't light!
 
  	If Gameover=0 then
 
  		For Each Light in LightKeys 'resets matching Key Lights
  			light.state = 0
  		Next
 
  	end if
 
end Sub

' *** Grotto ***
 
' Grotto scores 1000 points for each key light lit, and adds a bonus for each key. 
' Once all keys are lit, then it will give 25000 points, and 5 bonus. I cheated here a bit, but it was
' done to prevent confusion more than anything, to get it EXACTLY like Playboy would have taken a lot more
' code, that would have been pretty complex, plus we would have needed more timers.
 
' We need a variable to tell the script what to do with each grotto light lit
	Dim GrottoCount
 
' handles the 5000 score instead of 1000 points if 25k light is on
	Dim Grotto25
 
 ' And this sets a random value for the kicker
 Dim KF1823
 
' Now we do the Grotto Kicker, which we use as the main routine, and decide what to do from there
 
Sub KickerGrotto_Hit()
 	
 	' stop sounds if playing
	StopAllSounds() 
 	
 ' We now set the Grotto kicker force, but we want a random value, so we set it as a variable. We already
 ' have a randomize statement at the top of the script, so we set our intial kicker force at 18, and then
 ' add a random number between 1 and 6 to it, so the kicker force will be set from 18 to 24.
 	KF1823=18+((int(rnd(1)*6)))
 
 	' you may tilt just before the ball hits the kicker, so just kick the ball back out, then exit sub
 	' this is the real easy way to do it, but code snobs may wave a finger at you, but then, who cares?
 	' It's your game, not theirs.
 
 	' if a tilt has happened, the value for tilt is 1, so we check this first. If tilt=0 (untilted)
 	' then the script will ignore this.
 
 	If tilt=1 then
 
 		' We still have to make sure the ball kicks back out, or it will just get stuck there
 
 		KickerGrotto.kick 0, KF1823
 		
 		PlaySound "kicker"
 
 		' and to prevent execution of the rest of the code, we tell the script to leave this sub, and
 		' not do the rest of the code
 
 		Exit sub
 
 	end if

 	' Since we are not in a tilt state, lets start the rest of the code for the grotto.
 	'
 	' As complex as the keys are, the grotto is even more. If you are a beginner, you may have a lot
 	' of problems with understanding this, so I will add a lot of remarks, but this is for the more
 	' experienced scripter.
 	'
 	' Each grotto light lit will add 1000 points, and one bonus. If all 5 lights are lit, then it's
 	' 25k and 5 bonus instead. We have to tell the script how to do this, to be able to reconize that.
 	' We do this the easist way possible, we look at the light state for each light, and when that light 
 	' is on, we increase the variable (GrottoCount) by 1.
 	' But we don't want the value of GrottoCount to go beyond 5 (5 grotto lights means GrottoCount=5) so
 	' we write it so everytime a ball is in the Grotto Kicker, we force it to recount everytime, that's why
 	' we restart GrottoCount at 0, then we recount the lights to get the final value.
 	'
 	' SIDE NOTE: For some strange reason, Playboy actually had a score and a sound if there were no keys
 	' and grotto lights on at all, which made no sense, because it's impossible to hit the grotto without
 	' one key being lit. It's NOT coded here because of that.
 
 	GrottoCount=0 ' reset to 0, so we can recount, in case a new light is on since the last time
 	
 	' Now, we see the lightState, and add one to GrottoCount if it's on
 
 	If LightGrotto1.state = 1 then GrottoCount=GrottoCount+1
 	If LightGrotto2.state = 1 then GrottoCount=GrottoCount+1
 	If LightGrotto3.state = 1 then GrottoCount=GrottoCount+1
 	If LightGrotto4.state = 1 then GrottoCount=GrottoCount+1
 	If LightGrotto5.state = 1 then GrottoCount=GrottoCount+1
 
 	' By counting the lights turned on, and using that number for the GrottoCount number, now we can use
 	' that value to do what's needed. 
 
 	' Now we see if GrottoCount = 5 first, which is maximum value. We need to play that special sound before
 	' we start the count, as Playboy had a special routine and sound if all 5 lights were turned on, so we 
 	' play the sound here, and set the timer to delay until after that sound is finished playing, and then 
 	' we start the count. All the lights have to be on, if not, then the script will ignore this next
 	' section of the code.
 	'
 	' You will notice we use the TimerInterval to set different times, depending on whether the GrottoCount
 	' is 5 or not, before we call TimerGrotto to start the Count for the Grotto value.
 	'resets matching Key Lights
 
		If GrottoCount=5 then ' if all lights are on
 
		' I cut the sound out for this, and then "glue" the complete sound together, so it will play
 		' this sound first, run a timer delay, and then play the sounds for the bonus
 
		' This is a "special" sound that Bally added	
			PlaySound "Grotto25"
 
		' Playboy added 5000 with each portion of the sound, but to be honest, lets not get that anal...
 		' Instead, we set a variable for the TimerGrotto Cound, where we use it to change the score
 		' from 1000 points, to 5000 points. We also just switch it off there after the count is done
 		' so we don't have errors with the next player.
 
 			Grotto25=1

		 ' we wasted a timer just as a example, but it's a good demo of how to add a delay for a special
 		' sound. Once this is finished, then it will point to the Grotto count routine.
 
			TimerGrottoSound.Interval = 2500 ' match the timer sound to the total time that sound plays
			TimerGrottoSound.Enabled = 1 ' and start the grotto count
 
		else
 
 	' if there are lights lit in the grotto, but not ALL of them. 
 	' This will happen only if GrottoCount is between 0 and 5
 
			If GrottoCount=<0 then 
 				AddScore 500
 				
 				' we use the GetScoreBells variable to decide if we want to use the built in sound
				' system for Bally/EM type scoring or not. If we don't then set GetScoreBells to 0
				' and add the sound here. The GetScoreBells feature, if on (GetBalls=1) will play a set
				' sound, and is already added to the engine
				If GetScoreBells=0 then PlaySound "ButtonOn"
				
 			end if
 
			TimerGrotto.Interval = 250 ' okay, a quarter second delay, just seems to be more polished
			TimerGrotto.Enabled = True ' and start the grotto count
 
	 end if

end sub

 '
 Sub TimerGrottoSound_Timer()
 
 	TimerGrottoSound.Enabled = 0
 
 	If gameover=0 and tilt=0 then
 		TimerGrotto.Interval = 250
 		TimerGrotto.Enabled = True ' and start the grotto count
 	end if
 
 	' Of course someone is gonna try and tilt the game while it's in the game
 
 	If tilt=1 then
 		KickerGrotto.kick 0, KF1823
 		PlaySound "kicker"
 	end if
 
 end sub
 
' Almost done (Finally) Now lets do the Grotto countdown before we kick the ball back into play
' As Mentioned before, the Grotto in Playboy is really a very simple bonus countdown system, just there's
' 5 lights is all. We already handled any extra scoring above, so lets just see what our GrottoCount
' is, and count it down just like a end of ball bonus countdown.
 
Sub TimerGrotto_Timer()
 
 	' Sometimes, a player will tilt while the ball is in the grotto (don't ask me why, some people
 	' do so they can point a finger and say you screwed up. Must give them a superiority complex or
 	' something) and it's counting... so...
 
 	If tilt=1 then ' tilted while here
 		' We have to MAKE SURE the timer is switched off here
 		TimerGrotto.Enabled = 0
 		' reset variables
 		GrottoCount = 0
 		' make sure that 5000 score for 25k light is off, or all players will start scoring it
 		Grotto25=0
 		' make sure kicker timer is off
    	KickerGrotto.TimerEnabled=0
 		' kick ball out
 		KickerGrotto.kick 0, KF1823
 		PlaySound "kicker"
		Exit sub
 	end if
 
 	 ' This is for if there are still counts left to do. The interval is the time between each count
 	' We only turn off this timer when GrottoCount=0, so this will just keep looping back to the start 
 	' of this subroutine untill it reaches TimerGrotto.Enabled = 0
 
 	'TimerBonus.Interval = 250
 
	' We go into this if/then section if there are any lights lit in the Grotto.
	' We reuse the variable 'BonusCounted' and set to true to make sure that we only count once per 
 	' timer cycle.
 
 	 BonusCounted = False
 
 	' Now we start the routine, first off, we have to tell it to execute this part of the code if 
 	' GrottoCount IS NOT 0. This will add the score, the bonus, and the sound
 
 	If GrottoCount > 0 Then 
 
 		' adds the score at the same time as each bonus
 
 		If Grotto25 = 0 then
 			addscore (1000)
 		else
 
 		' we cheat a bit, pb matched the score with the sound, but let's be simplier. we add 5 counts at
 		' this section instead.
 		' Notice the GetScore? Yeap, 2 scoring systems, the Bally style, and this which allows you to
 		' to bypass the "EM type" scoring system. It just looks nicer to have it update the display only 5
 		' times as opposed to 25 times...
 
 			GetScore (5000)
 			
 		' Because we use the GetScore, and not the AddScore (which doesn't sound nice anyway)
 		' we add the proper sound for this, which happens to be the same sound as the bonus
 		' and 1000 point sound.
 		
 			PlaySound "Bell1000"
 
 		end if
		 BonusCounted = True
 		AddBonus()
 
 		' plays a sound for each bonus. We put it here so it doesn't play a extra sound 
 		' afterwards. To make timing easier, we stop the sound first, to prevent "overlap"
 		' Playboy used the same sound as the Bonus, but cut it off halfway when it repeated the count
 		' I force the last sound to play fully here, as it sounds a lot better than being cut off in
 		' the middle of the sound playing
 
 		If GrottoCount > 1 then
 		
 		' we use the GetScoreBells variable to decide if we want to use the built in sound
		' system for Bally/EM type scoring or not. If we don't then set GetScoreBells to 0
		' and add the sound here. The GetScoreBells feature, if on (GetBalls=1) will play a set
		' sound, and is already added to the engine
		If GetScoreBells=0 then PlaySound "Bell1000"
		
 		' reset the variable
 		BonusCounted = True
 
 	End If
 
 	' With every count, we subtract it by one each time until GrottoCount is 0. We force it to loop back
 	' otherwise.
 
 	GrottoCount = GrottoCount - 1 
 	
 	' Now it's time to see what the GrottoCount value is, and act accordingly (and we make sure we are not 
 	' tilted either, as some people will test this just to be a pain in the ass)
 	' We decreased the count by one already, so we check if GrottoCount=0 first. If it is, that means
 	' it's finished so...
 
 	If GrottoCount =< 0 Then 	' If we have counted all Grotto lights
 
 		' We have to MAKE SURE the timer is switched off here, or it will just count forever
 		TimerGrotto.Enabled = 0
 
 		' play that end sound the game makes after the count is finished. I added a 500 ms blank sound
 		' in front, to serve as a delay so it doesn't blend in with the Bonus sound
 		PlaySound "GrottoEnd" 
 
 		' set the amount of delay we want for that sound to finish playing
 		KickerGrotto.TimerInterval=3700
 
 		' BEFORE we call the routine to kick the ball back in play
    	KickerGrotto.TimerEnabled=True	' Yeap, another timer, for the kicker
 
 		' make sure that 5000 score for 25k light is off, or all players will start scoring it
 		Grotto25=0
 
 		' and LEAVE the sub, do not execute this sub anymore
 		Exit sub
 	end if
 end if
end sub

 ' And this is the timer to kick the ball back out. Again, only used for a delay
Sub KickerGrotto_Timer()
 
 	KickerGrotto.TimerEnabled=False	
 
 	If Gameover=0 then
 		KickerGrotto.kick 0, KF1823
 		PlaySound "kicker"
 	end if

end sub