' code snippet file for use with shivaEngine3 
' released: 5.25.06
'
' *** COPYRIGHT NOTICE ***
'
' written by shiva
' Thanks to all the other authors
' Contact Info : p_d_sanderson@hotmail.com
'
' All rights are reserved by p.d.sanderson (shiva)
' You may release, or modify for release any portion of this product, as long as it is not 
' part of a commercial product or venture. 
' This code snippet was meant to be expanded, so please contact the author for additions 
' to this base script. All submissions welcome.
'
' The above copyright and remarks MUST be included with this table. Please credit use of
' this script for your own tables.
'
' Please keep any modifications for release as separate code snippet files so others can use 
' it for their tables.
'
' *** 1823 - (Playboy) Right Target Banks / Inlanes / Outlanes ***
'
' Main target routine, using a collection, and the same method as the wire triggers for the In/Outlanes.
' The code to this is actually very simple, it's almost the same as the Button target code used for
' the Calendar feature to the left of the table. This though uses a second target placed at the back
' of each target, that does a "push" in effect. If you play Playboy, you will notice this.
' What we do is in the SetNewBall() HOOK subroutine, we set the back set of targets to "down", so
' they are not visible, while the main targets in front are. When the ball hits the front set of targets
' it drops down, and pops up the back target imediately. So it looks like the target is being pushed in.
' we then use a timer with a set interval (I used 50) that when the interval is finished, drops that back
' target. I use a timer object for that, and called it "TimerDT1823a". This just controls the amount of time
' you want for the delay that the back target will show before it drops.
' A reminder with targets is the first set should "Has Hit Event" and "Can Drop" CHECKED. The second back
' set of targets only needs "Can Drop" Checked, as there is no hit event for it
'
' There is also a second Timer object, called "TimerDT1823b". This controls the amount of time for the delay
' when all targets are down, and then resets. I do this because it looks a bit better than if all the
' targets pop up suddenly at the last target hit, and the delay also gives a bit of time for the ball to
' clear the area so it doesn't automatically drop targets that pop up.
' Because there are two sets of target banks, you need 2 collections, one for each set. I create my 2
' collections (called DT1823a for the front set, and DT1823b for the back set... yes, I am that anal)
' create my targets, and add them into the collection.
'
' BTW, Index in the code keeps track of which target is made. You will notice that I set the
' Target name to have a number at the end. (I do the same with any matching lights) This routine checks
' the target based on the Index, and then a simple check to see if all the targets are down.
' If not, then it will exit out of the sub. If it does find that all targets are down, then it will execute 
' the code, (In Playboy, light or award the Special) and then point to a timer to reset the targets up
' We also have the outlane code here, as they are tied in with the target banks
 
' This handles the variable controling how many times a target bank is made
 
Dim DT1823TBankCount ' Holds value for amount of times target bank is down 
 
' Playboy and other Ballys have pin settings, that will either alternate the outlane lights, or set
' both to on. They also did this with the same objects that are used to set the railway lights, but
' this is set so every time a object is hit, it will just change from one outlane lit to another
' and not require 3 hits. The railway type feature though is not found on every Early SS type Bally
' but this is, so to make it easier for use with your table, this routine is seperate so you can
' copy and paste it, and then just add AlternateOutlaneLights() to your hit event code that you want
' to alternate the lights
'
' We have one problem, how to get the system to not automatically switch the lights on until we want
' it to, which is when the target bank is completed first. We have to use a variable for this to indicate
' this feature is on and off

Dim OutlanesLite ' variable used for lighting Outlanes

' First, we set up our code for the engine to read and set the opening variables at Table Start, and for
' each new ball. We call it by the sub name: SetTargets1823() and place it in the SetNewBall(). A lot easier
' to have one line instead of several. and also, this means you can have several target banks in your game
' without getting confused, or worse, getting the script confused. Remember that we have separate skill
' level coding here as well.
'	
' Set Initial values, called by the SetNewBall() HOOK
Sub SetTargets1823()

 	' Resets the target bank so all front targets back up
 	ResetTargets()
 
 	' reset the variable to 0 so we make sure it's cleared if there is other players
 	DT1823TBankCount=0
	OutlanesLite=0
 
 	' Check to see the skill level set, and if the special light is on. We add the gameover to prevent the
 	' variable from increasing during attract mode. We look for SetSkillLevel is at 0 (easy setting) or 1 
 	' first and decide what to do from there.
 
 	If SetSkillLevel<1 and gameover=0  then
 
 	' The Target Special light is added to the memory system (it would be in all those "Set MemorySlot"
 	' lines), so that means the the light state is restored if on at the start of a players next ball. 
 	' All we have to do then is match the DT1823TBankCount value so the code reconizes it, and will
 	' award a special when those targets are all down.
 
 		if LightDT1823.State=1 then ' Look to see if Target Special light is on
 			
 			' add the value so the script doesn't lose track when the bank goes down again
 			DT1823TBankCount=1 
 
 			' Light outlanes 25000
 			OutlanesLite=1 ' we make sure we set this to 1, so it indicates that the outlanes should be lit
 
 			' and of course, we better turn on the outlane lights. GetSkillSet=0 will switch on both
 			if SetSkillLevel = 0 then
 				for each light in LightOutlanes
					Light.State=1
 				next
 			else 'if we are higher than 0, then just one light will switch on
 				LightOutlane1.State=1
 			end if
 		end if

 	' If you remember from above, we use the else statement to execute code if SetSkillLevel IS NOT
 	' 0 or 1 (In other words, it's SetSkillLevel=2)
 	else
 
 	' If skill level is above the "easy setting". We want to turn off that special light then.
 	' The DT1823TBankCount is already set to 0 at the top so we just need to switch the special light off
 		LightDT1823.State=0
 	end if
 
end sub
 
' This is the part where we get to the more complex code, especially with collections. You will see special
' code like this "For each target in DT1823a" and similar code for lights. You don't have to worry about
' it, targets and lights are a variable, but they are already set up in the engine with Dim Statements.
' We use the For/Next statements to check each object listed in the collection individually, which is a 
' lot faster and easier than writing seperate hit codes for each object we want.

' I only need to point to one collection here, it's all driven with in this subroutine
 
Sub DT1823a_hit( Index )
 
 	' See which target is hit based on the order in the collection
 	DT1823a( Index ).isdropped = 1 ' Drop that Front target down

 	StopAllSounds() ' stop sounds if playing
 	PlaySound "TargetDown"	' drop target mechanical sound
 
 	' better check it's not tilted first, and that we are actually in a game
	If tilt=0 and gameover=0 then
 
 		AddScore 500 ' adds 500 points
 
 		' Adds count to Railway Feature for 5000 points (every 3rd time) Other objects also trigger
 		' the count as well. See the Railway section within the code for a more detailed description
 		GetSpecialFeatureCount()
 
 		' The same, but for if the Outlanes are lit (This will change with every hit though)
 		AlternateOutlaneLights()
 
		' here we check to see if all the targets are down. if not, then we exit from this sub
		For	each target in DT1823a
 
		' First we check if one or more targets are not down, if they are ALL down, then this will 
 		' be ignored
			If target.isdropped <> True Then
  
 				' we use the GetScoreBells variable to decide if we want to use the built in sound
				' system for Bally/EM type scoring or not. If we don't then set GetScoreBells to 0
				' and add the sound here. The GetScoreBells feature, if on (GetBalls=1) will play a set
				' sound, and is already added to the engine
				If GetScoreBells=0 then PlaySound "Target"	' drop target sound electronic
				
 		' Pop up the back target for the "pushed in" effect. Notice I put this here instead of at the
 		' top. The reason is I don't want the 2 timers to go off at once, as it could cause the
 		' computer to "shudder" and drop frames. The timer object in VP is very computer intensive,
 		' so what I do is only have the pushed in effect for all targets BUT THE LAST ONE, so I can
 		' remove the timer call and save resources
 
 			 	DT1823b( Index ).isdropped = 0 ' drop the target
 
 		' There are 2 timers, this one is for the separate targets, to give a pushed in effect
				TimerDT1823a.Enabled=1
 
 		' Leave, do not execute after this, as it's for all targets made
				Exit Sub
 
			end if
 
		Next
 	
 	' This is if ALL targets are down as set in the collection. For example purposes, I used SteveOz Blazing
 	' Table as a example here, as it's simple and the way I would do it anyway. This adds a variable, 
 	' DT1823TBankCount, which keep track of how many times the bank is made during a ball. We reset
 	' this at a start of a new ball as well, in the SetNewBall() HOOK sub
 	
		DT1823TBankCount = DT1823TBankCount + 1 ' Add one to variable that indicates how many times a bank made
 	
 	' Now we use a case setting to give special instructions on what we want to happen with each
 	' target bank down. You can add anything here, from multipliers, extra balls, specials
 	' whatever. We only need 2 case statements here, so it will execute case 1 first, then case 2
 	' will execute the 2nd time a bank is made. Case Else means everytime afterwards if there's
 	' no more cases defined. It shouldn't trigger, just a error catcher 
 	' To add a third case, just put in case 3 and the code, and so on, and move the DT1823TBankCount=0 line
 	' to the last case. You can have as many cases as you want. 
 	' Setting DT1823TBankCount to 0 means it will causes a loop back to the first case. 
 	' We do this because Playboy looped as well so the special at the target banks are lit every second time
 
		Select Case DT1823TBankCount
 
 		Case 1
 			LightDT1823.State=1 ' light Special Light
 			' Light outlanes 25000
 			OutlanesLite=1 ' we make sure we set this to 1, so it indicates that the outlanes should be lit
 			' and of course, we better turn on the outlane lights. GetSkillSet=0 will switch on both
 			if SetSkillLevel = 0 then
 				for each light in LightOutlanes
					Light.State=1
 				next
 			else 'if we are higher than 0, then just one light will switch on
 				' Note the Index=1? That means only the one light in that collection will light
 				LightOutlanes(Index=1).State=1
 			end if
 
 		Case 2
 
 		' You got the special!
 			LightDT1823.State=0 ' Light off
 
 		' Add a Credit (Preset in the engine, so everytime you want a special, just add GetSpecial() to
 		' your code)
 			GetSpecial()
 
 		' Reset targets to start over
 			DT1823TBankCount=0 
 
 		Case Else ' in case DT1823TBankCount goes over 2
 			DT1823TBankCount=0
 
		End Select
 	
 	' Notice we put the single Target sound in the code that checks if all targets are down? This way
 	' if not all the targets are down, it will play that sound, and then exit the sub, as we want a 
 	' separate sound to play instead if ALL the targets are down, so that's why. 
 	' This will play the Bank sound instead if all targets are down.
 
 		PlaySound "TargetBank"
 
 	' Now we set the target bank to reset, with a timer. We use a timer object as opposed to the built in 
 	' target bank timer, to save a lot of code, so if you wish to change the amount of time that the 
 	' targets reset, change the interval as set in the TimerDT1823b object in the editor (i used 750
 	' which is 3/4 of a second as a delay)
 
		TimerDT1823b.Enabled=1
 
 	end if

End Sub
 
' This is the Timer for the single target pushed in effect
 
Sub TimerDT1823a_Timer()

 	TimerDT1823a.Enabled = 0 '0 = False, or turn off the timer
 
 	' Note there is no tilt code, as this is a mechanical effect, and we don't want that back target still 
 	' up, we just put in the gameover code to prevent the timer from running at the start of the table
 
 	If gameover=0 then	
		' Pop down the back target for the "pushed in" effect
		For Each target in DT1823b
			target.IsDropped = 1
		Next
 	end if
 
 End Sub
 
' Timer for Bank reset, when all targets are down. This is just a delay, and then we call the reset sub
' from within this timer. The reason we do it this way, is because we also call the same routine at
' the start of a new Ball(SetNewBall() HOOK sub), so we save a bit of duplicate code by having it as 
' a separate sub
 
 Sub TimerDT1823b_Timer()
 
 	TimerDT1823b.Enabled = 0 '0 = False, or turn off the timer

 	' Note there is no tilt code, as this is a mechanical effect, and we don't want that back target still 
 	' up, we just put in the gameover code to prevent the timer from running at the start of the table
 
 	if gameover=0 then
		ResetTargets() ' reset the targets
 	end if
 
 End Sub
 
' Reset routine for Right targets. We also call this at SetNewBall() HOOK sub, to reset the target bank, 
' that's why this is in a separate routine
 
 Sub ResetTargets()
  
 	'resets drop targets, we make sure the front targets are up
 	For Each target in DT1823a
     	target.IsDropped = 0
 	Next
 	
 	' and the pushed in effect back targets are down
 	For Each target in DT1823b
     	target.IsDropped = 1
 	Next
 
    PlaySound "TargetUp"

End Sub 
 
' Another set of two collections for the outlanes, and because Playboy doesn't have multiball, we cheat
' a bit on the code, as we don't have to worry about both Outlanes being triggered at once. Like a lot of
' the other code here, we have a collection for the Outlanes, and a collection for the Outlane lights. We
' also use a hit and unhit event just to handle the wire triggers, like the Railway code does.
 
Sub Outlanes_Hit(Index)
 
 	if tilt=0 and gameover=0 then
 		StopAllSounds() ' stop sounds if playing 
 
 		' Use the second collection for the lights. because we named the lights to have the same
 		' number as the outlane triggers, it makes this very simple... This way, we could have
 		' "rotating lights" for the outlane if we want
 		' lets see if that matching light is on
 
 		If LightOutlanes( Index ).state = 0 then ' the matching light is off
 		 
 			AddScore 1000
 			
 			' we use the GetScoreBells variable to decide if we want to use the built in sound
			' system for Bally/EM type scoring or not. If we don't then set GetScoreBells to 0
			' and add the sound here. The GetScoreBells feature, if on (GetBalls=1) will play a set
			' sound, and is already added to the engine
			If GetScoreBells=0 then PlaySound "Outlanes":end if
 			
 		else ' the matching light is on
 			AddScore 25000
 			
 			PlaySound "OutlaneOn"
 			
 		end if
 
 	end if
 
end sub
 
' This is a very simple example to alternate the outlane lights. It's pretty much the same thing as the
' Railway Lane code, but this will alternate a light between both outlanes, and will do it with every
' hit, as opposed to 3 like the Railway

Sub AlternateOutlaneLights()
 
 	' Now we use the OutlanesLite variable value to execute the code. If OutlanesLite=0, then it will
 	' just exit, but if OutlanesLite=1, then it will do the code to alternate the lights
 
 	If OutlanesLite=0 then
 		Exit Sub ' the outlane lights are NOT on, so leave this subroutine
 	else
 
 	' We could impress you with dramatic complex looking code, or we could just do it the simple way... 
 	' The only drawback is you have to make sure you have a LightOutlane 1 and a LightOutlane 2
 	' We look at the skilllevel, see if its 1 (average) or higher. In our setup code if you remember
 	' we only switch off the lights at a new ball with the higest skill setting, so at skill 1, the lights
 	' will alternate, and they will be turned back on at the start of a new ball. At the highest skill 
 	' level though, the lights are switched off at the start of a new ball, so you will have to make the 
 	' target banks again to relight them
 
 		If SetSkillLevel>0 then
			If LightOutlane1.State=0 then ' Use this light as a basis, if it's Off
				LightOutlane1.State=1 ' switch this light on then
				LightOutlane2.State=0 ' and switch the other off
			else ' if this light is on instead, then switch the lights
				LightOutlane1.State=0
				LightOutlane2.State=1
			end if
 		end if
 
 	' This is for the lowest skill setting. Not only do they not alternate, it will just light both lights
 	' in the collection, but it also will save them as well
 
 		If SetSkillLevel=0 then
 			For each light in LightOutlanes
 				light.state=1
 			next
 		end if
 	end if
 
end sub
 
' Now lets do the wire triggers, but we call each trigger. We could use a collection, but this is just
' as simple, so use the Hit to drop the wires down (There's a darker set underneath, to give the 
' dropped effect, just like the railway wire triggers)
 
Sub Outlane1_Hit()
 	WireOutlaneLeft1.IsDropped=1
 	WireOutlaneLeft2.IsDropped=1
end sub
 
' and a Unhit event to pop those triggers back up...
Sub Outlane1_UnHit()
 	WireOutlaneLeft1.IsDropped=0
 	WireOutlaneLeft2.IsDropped=0
end sub
 
' and now the other side...
 
Sub Outlane2_Hit():WireOutlaneRight1.IsDropped=1:WireOutlaneRight2.IsDropped=1:end sub
Sub Outlane2_UnHit():WireOutlaneRight1.IsDropped=0:WireOutlaneRight2.IsDropped=0:end sub

' *** 1823 - (Playboy) Inlanes ***
 
' while we are at it, lets do the Inlanes, but add the score, as there is no need for a collection,
' there's only one sound, and other than the simple 1000 points and sound, nothing else to code.
' We use the Hit and Unhit code instead of timers to handle the wire effect. 
' (Explained fully in the Outlane code)
 
Sub LeftInlane_Hit()
 	WireInlaneLeft1.IsDropped=1:WireInlaneLeft2.IsDropped=1
 	
 	' Check to see if we are not tilted first. Note we stop the sound first before we play
 	' it, this prevents 2 sounds at once if it's a double trigger hit.
 	if tilt=0 then
		AddScore 500
		
		' we use the GetScoreBells variable to decide if we want to use the built in sound
		' system for Bally/EM type scoring or not. If we don't then set GetScoreBells to 0
		' and add the sound here. The GetScoreBells feature, if on (GetBalls=1) will play a set
		' sound, and is already added to the engine
		If GetScoreBells=0 then StopSound "Target":PlaySound "Target"
 	end if
end sub
 
Sub LeftInlane_UnHit():WireInlaneLeft1.IsDropped=0:WireInlaneLeft2.IsDropped=0:end sub
 
Sub RightInlane_Hit()
 	WireInlaneRight1.IsDropped=1:WireInlaneRight2.IsDropped=1
 	
 	' Check to see if we are not tilted first
 	if tilt=0 then
		AddScore 500
		
		' we use the GetScoreBells variable to decide if we want to use the built in sound
		' system for Bally/EM type scoring or not. If we don't then set GetScoreBells to 0
		' and add the sound here. The GetScoreBells feature, if on (GetBalls=1) will play a set
		' sound, and is already added to the engine
		If GetScoreBells=0 then StopSound "Target":PlaySound "Target"
		
 	end if
end sub
 
Sub RightInlane_UnHit():WireInlaneRight1.IsDropped=0:WireInlaneRight2.IsDropped=0:end sub